@@ -2,8 +2,8 @@
 NULL
 
 formula2aes <- function(formula, template) {
-  fs <- f_formula_slots(formula) %>% unlist()
-  ts <- f_formula_slots(template) %>% unlist()
+  fs <- f_formula_slots(formula) |> unlist()
+  ts <- f_formula_slots(template) |> unlist()
   names(fs) <-
     sapply(ts, function(x) as.character(rlang::f_rhs(x)))
   # names(fs) <- sapply(ts, as.character)
@@ -13,7 +13,7 @@ formula2aes <- function(formula, template) {
 list2aes <- function(l) {
   mapping <- aes()
   for (i in 1:length(l)) {
-    new_mapping <- aes(a = !!l[[i]][[2]]) %>% setNames(names(l)[i])
+    new_mapping <- aes(a = !!l[[i]][[2]]) |> setNames(names(l)[i])
     mapping <- modifyList(mapping, new_mapping)
   }
   mapping
