@@ -1,8 +1,5 @@
 # This allows us to use these functions without attaching the packages they come from.
 
-#' @importFrom magrittr %>%
-#' @export
-magrittr::`%>%`
 
 #' @importFrom mosaicCore makeFun
 #' @export
@@ -16,15 +13,16 @@ mosaicCore::df_stats
 #' @export
 mosaicCore::na.warn
 
-#' @importFrom ggforce stat_sina StatSina
-#' @export
-ggforce::stat_sina
-#' @export
-ggforce::StatSina
-
-#' @importFrom ggforce geom_sina
-#' @export
-ggforce::geom_sina
+# #
+# #' @importFrom ggforce stat_sina StatSina
+# #' @export
+# ggforce::stat_sina
+# #' @export
+# ggforce::StatSina
+# #
+# #' @importFrom ggforce geom_sina
+# #' @export
+# ggforce::geom_sina
 
 
 #' @importFrom labelled var_label
